# Includes all asteroids, moon ore and ice. All items that can be compressed or refined for minerals*
ORE_EVE_GROUPS = [
    450,
    451,
    452,
    453,
    454,
    455,
    456,
    457,
    458,
    459,
    460,
    461,
    462,
    465,
    467,
    468,
    469,
    1884,
    1911,
    1920,
    1921,
    1922,
    1923,
    2024,
    2029,
    4029,
    4030,
    4031,
    4094,
]

OPE_EVE_GROUPS = [493]

BONDS_EVE_GROUPS = [1248]

BLUE_LOOT_TYPE_IDS = [
    30744,
    30745,
    30746,
    30747,
]

RED_LOOT_TYPE_IDS = [
    48121,
]
